@@ -1,4 +1,4 @@
-/* $Id: chartable_accessible.c,v 1.9 2003/05/14 15:04:36 padraigo Exp $ */
+/* $Id: chartable_accessible.c 1300 2007-01-19 18:32:05Z chpe $ */
 /* 
  * Copyright (c) 2003  Sun Microsystems Inc.
  *
@@ -25,20 +25,12 @@
 #include <string.h>
 #include <gtk/gtk.h>
 
-#include <gucharmap/gucharmap.h>
+#include "gucharmap.h"
+#include "gucharmap-table-private.h"
 #include "chartable_accessible.h"
 #include "charcell_accessible.h"
 
-
-extern gint gucharmap_table_x_offset (GucharmapTable *chartable, 
-                                      gint col);
-extern gint gucharmap_table_y_offset (GucharmapTable *chartable, 
-                                      gint row);
-extern gint gucharmap_table_unichar_column (GucharmapTable *chartable, 
-                                            gunichar uc);
-
-
-typedef struct 
+typedef struct
 {
   AtkObject *cell;
   gint      index;
@@ -104,8 +96,8 @@ set_cell_visibility (GucharmapTable  *chartable,
 {
   charcell_accessible_add_state (cell, ATK_STATE_VISIBLE, emit_signal);
 
-  if (cell->index >= chartable->page_first_char &&
-      cell->index < chartable->page_first_char 
+  if (cell->index >= chartable->page_first_cell &&
+      cell->index < chartable->page_first_cell 
                     + chartable->rows * chartable->cols)
     {
       charcell_accessible_add_state (cell, ATK_STATE_SHOWING, emit_signal);
@@ -302,7 +294,7 @@ chartable_accessible_ref_accessible_at_point (AtkComponent *component,
 
   for (col = 0; col < chartable->cols; col++) 
     {
-      if (x_pos < gucharmap_table_x_offset (chartable, col))
+      if (x_pos < _gucharmap_table_x_offset (chartable, col))
         {
           col--;
           break;
@@ -313,7 +305,7 @@ chartable_accessible_ref_accessible_at_point (AtkComponent *component,
 
   for (row = 0; row < chartable->rows; row++) 
     {
-      if (y_pos < gucharmap_table_y_offset (chartable, row))
+      if (y_pos < _gucharmap_table_y_offset (chartable, row))
         {
           row--;
           break;
@@ -322,7 +314,7 @@ chartable_accessible_ref_accessible_at_point (AtkComponent *component,
   if (row == chartable->rows || row < 0)
     return NULL;
 
-  row += chartable->page_first_char / chartable->cols;
+  row += chartable->page_first_cell / chartable->cols;
 
   return chartable_accessible_ref_at (ATK_TABLE (component), row, col);
 }
@@ -478,7 +470,7 @@ find_object (GucharmapTable   *chartable,
   gint row, column;
 
   row = uc / chartable->cols;
-  column = gucharmap_table_unichar_column (chartable, uc);
+  column = _gucharmap_table_cell_column (chartable, uc);
 
   return atk_table_ref_at (ATK_TABLE (obj), row, column);
 }
@@ -528,7 +520,7 @@ chartable_accessible_initialize (AtkObject *obj,
   g_signal_connect (chartable, "set_active_char",
                     G_CALLBACK (active_char_set), obj);
 
-  focus_obj = find_object (chartable, chartable->active_char, obj);
+  focus_obj = find_object (chartable, chartable->active_cell, obj);
   set_focus_object (obj, focus_obj);  
 }
 
